@@ -189,13 +189,13 @@ def cli(target_dir, start_time, end_time, author, ext_names):
         for code_name in codes.keys():
             result[item][code_name] = [0, 0]
 
-        for strings in insertions_and_deletions[:]:
+        for strings in insertions_and_deletions:
             for code_name in codes.keys():
                 if commit_is_code(strings, patterns[code_name]):
                     str_tmp = re.findall(r'[0-9]+?\t', strings)
                     result[item][code_name][0] += int(str_tmp[0][:-1])
                     result[item][code_name][1] += int(str_tmp[1][:-1])
-                    insertions_and_deletions.remove(strings)
+                    # insertions_and_deletions.remove(strings)
 
         date_raw = re.findall(
             r'Date: {3}[A-Z][a-z]{2} [A-Z][a-z]{2} [0-9]+? [0-9]{2}:[0-9]{2}:[0-9]{2} [0-9]{4}',
@@ -260,3 +260,5 @@ def cli(target_dir, start_time, end_time, author, ext_names):
                       date[busy_day],
                       ' 次. ',
                       style="bold white")
+
+
